@@ -1,5 +1,6 @@
 import inspect
 from threading import Thread
+import yaml
 
 from ..base.user_proxy_model import UserProxyModel
 from ..base.exceptions import StopProcessing, ExitHandler
@@ -101,9 +102,13 @@ def process_update(update: Update) -> None:
 
 def process_updates(updates: list[Update]):
     for update in updates:
-        logger.info(cast(update, dict))
         Thread(target=lambda: process_update(update)).start()
 
+        as_dict = cast(update, dict)
+        as_string = yaml.dump(as_dict, allow_unicode=True, sort_keys=False)
+        as_string = '\n' + as_string + '\n'
+        logger.info(as_string)
+
 
 def start_polling(skip_updates: bool):
     offset = None
